
<?php
/**
 * Plugin Name: Encurtador de URL em Massa RDH 100
 * Description: Um plugin simples para encurtar até 100 URLs longas de uma só vez.
 * Version: 1.1
 * Author: Rafael Davi Hack
 * Author URI: http://www.intersites.net.br
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class RDH_Mass_URL_Shortener {
    public function __construct() {
        add_action( 'admin_menu', array( $this, 'create_menu' ) );
        add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
        add_action( 'wp_ajax_rdh_shorten_urls', array( $this, 'shorten_urls' ) );
        add_action( 'init', array( $this, 'handle_redirect' ) );
    }

    public function create_menu() {
        add_menu_page(
            'Encurtador em Massa RDH 100',
            'Encurtador em Massa RDH 100',
            'manage_options',
            'rdh-mass-url-shortener',
            array( $this, 'shortener_page' ),
            'dashicons-admin-links'
        );
    }

    public function enqueue_scripts( $hook ) {
        if ( $hook !== 'toplevel_page_rdh-mass-url-shortener' ) {
            return;
        }
        wp_enqueue_style( 'rdh-style', plugin_dir_url( __FILE__ ) . 'style.css' );
        wp_enqueue_script( 'rdh-script', plugin_dir_url( __FILE__ ) . 'script.js', array('jquery'), null, true );
        wp_localize_script( 'rdh-script', 'rdh_ajax', array(
            'ajax_url' => admin_url( 'admin-ajax.php' ),
            'nonce'    => wp_create_nonce( 'rdh_nonce' )
        ));
    }

    public function shortener_page() {
        ?>
        <div class="wrap">
            <h1>Encurtador de URL em Massa RDH 100</h1>
            <form id="rdh-url-shortener-form" method="post">
                <textarea id="rdh-urls" name="rdh-urls" rows="10" cols="100" placeholder="Insira até 100 URLs, uma por linha..."></textarea>
                <br>
                <button type="button" id="rdh-shorten-btn" class="button button-primary">Converter todas as URLs para curtas</button>
            </form>
            <div id="rdh-results"></div>
        </div>
        <?php
    }

    public function shorten_urls() {
        check_ajax_referer( 'rdh_nonce', 'nonce' );

        if ( ! current_user_can( 'manage_options' ) ) {
            wp_send_json_error( 'Permissão negada.' );
        }

        $urls = isset( $_POST['urls'] ) ? $_POST['urls'] : array();
        if ( ! is_array( $urls ) || count( $urls ) > 100 ) {
            wp_send_json_error( 'Número inválido de URLs.' );
        }

        global $wpdb;
        $table_name = $wpdb->prefix . 'rdh_shortened_urls';

        if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
            $charset_collate = $wpdb->get_charset_collate();
            $sql = "CREATE TABLE $table_name (
                id mediumint(9) NOT NULL AUTO_INCREMENT,
                original_url text NOT NULL,
                short_code varchar(10) NOT NULL,
                PRIMARY KEY  (id),
                UNIQUE KEY short_code (short_code)
            ) $charset_collate;";
            require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
            dbDelta( $sql );
        }

        $results = array();
        foreach ( $urls as $url ) {
            $url = esc_url_raw( trim( $url ) );
            if ( filter_var( $url, FILTER_VALIDATE_URL ) ) {
                $short_code = substr( md5( $url . time() ), 0, 4 );
                $wpdb->insert(
                    $table_name,
                    array(
                        'original_url' => $url,
                        'short_code' => $short_code,
                    )
                );
                $short_url = home_url( '/' . $short_code );
                $results[] = array( 'original' => $url, 'short' => $short_url );
            }
        }

        wp_send_json_success( $results );
    }

    public function handle_redirect() {
        global $wpdb;
        $request = trim( $_SERVER['REQUEST_URI'], '/' );
        $table_name = $wpdb->prefix . 'rdh_shortened_urls';

        $row = $wpdb->get_row( $wpdb->prepare(
            "SELECT original_url FROM $table_name WHERE short_code = %s",
            $request
        ) );

        if ( $row ) {
            wp_redirect( $row->original_url, 301 );
            exit;
        }
    }
}

new RDH_Mass_URL_Shortener();
